==> read_native_channel_plugin-0.0.1.tar.gz: android/src/main/java/com/ivans/plugin/readNativeChannelPlugin/ReadNativeChannelPlugin.java <==
package com.ivans.plugin.readNativeChannelPlugin;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * ReadNativeChannelPlugin
 */
public class ReadNativeChannelPlugin implements MethodCallHandler ,FlutterPlugin{


    private MethodChannel channel;


    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "readNativeChannelPlugin");
        channel.setMethodCallHandler(new ReadNativeChannelPlugin());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getChannelName")) {
            result.success(getChannelName());
        } else {
            result.notImplemented();
        }
    }


    public String getChannelName() {
        return ChannelUtil.getChannel(BaseApplication.getContext(), "未获取渠道信息");
    }

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "readNativeChannelPlugin");
        channel.setMethodCallHandler(this);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
}

==> read_native_channel_plugin-0.0.2.tar.gz: android/src/main/java/com/ivans/plugin/readNativeChannelPlugin/ReadNativeChannelPlugin.java <==
package com.ivans.plugin.readNativeChannelPlugin;

import android.content.Context;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * ReadNativeChannelPlugin
 */
public class ReadNativeChannelPlugin implements MethodCallHandler, FlutterPlugin {


    private MethodChannel channel;

    private Context mContext;


    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "readNativeChannelPlugin");
        channel.setMethodCallHandler(new ReadNativeChannelPlugin());
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getChannelName")) {
            result.success(getChannelName());
        } else {
            result.notImplemented();
        }
    }


    public String getChannelName() {
        return ChannelUtil.getChannel(mContext, "未获取渠道信息");
    }

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "readNativeChannelPlugin");
        channel.setMethodCallHandler(this);
        mContext = flutterPluginBinding.getApplicationContext();
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }
}
